.. _api_reference:

==============================
Pydicom Complete API Reference
==============================

.. rubric:: Auto-generated API documentation

DICOM Dataset
=============
.. automodule:: pydicom.dataset

Modules related to DICOM File Input/Output
==========================================

Reading DICOM files - the filereader module
-------------------------------------------
.. automodule:: pydicom.filereader

Writing DICOM files - the filewriter module
-------------------------------------------
.. automodule:: pydicom.filewriter

Base classes for file I/O - the filebase module
-----------------------------------------------
.. automodule:: pydicom.filebase

Handling a DicomDir object - the dicomdir module
------------------------------------------------
.. automodule:: pydicom.dicomdir

Helper functions for reading files - the fileutil module
--------------------------------------------------------
.. automodule:: pydicom.fileutil

DICOM Tag related modules
=========================

DICOM data dictionary - the datadict module
-------------------------------------------
.. automodule:: pydicom.datadict

DICOM data elements - the dataelem module
----------------
.. automodule:: pydicom.dataelem

DICOM sequences - the sequence module
-------------------------------------
.. automodule:: pydicom.sequence

DICOM tags - the tag module
---------------------------
.. automodule:: pydicom.tag

DICOM tag values - the values module
------------------------------------
.. automodule:: pydicom.values

DICOM values with VM > 1 - the multival module
----------------------------------------------
.. automodule:: pydicom.multival

Handling of DICOM VRs - the valuerep module
-------------------------------------------
.. automodule:: pydicom.valuerep

Handling of character encoding - the charset module
--------------------------------------------------
.. automodule:: pydicom.charset

DICOM UIDs - the uid module
---------------------------
.. automodule:: pydicom.uid

Various helper modules
======================

Configuration of pydicom behavior - the config module
-----------------------------------------------------
.. automodule:: pydicom.config

Working with compressed pixel data - the encaps module
------------------------------------------------------
.. automodule:: pydicom.encaps

Miscellaneous helper functions - the misc module
------------------------------------------------
.. automodule:: pydicom.misc

Pydicom-specific exceptions - the errors module
-----------------------------------------------
.. automodule:: pydicom.errors
